# PreviewSubscriptionRequest


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**account_key** | **str** |  Customer account number or ID.  You must specify the account information either in this field or in the &#x60;previewAccountInfo&#x60; field with the following conditions:           * If you already have a customer account, specify the account number or ID in this field. * If you do not have a customer account, provide account information in the &#x60;previewAccountInfo&#x60; field.  | [optional] 
**contract_effective_date** | **date** | Effective contract date for this subscription, as yyyy-mm-dd.  | 
**customer_acceptance_date** | **date** | The date on which the services or products within a subscription have been accepted by the customer, as yyyy-mm-dd.  Default value is dependent on the value of other fields. See **Notes** section for more details.  | [optional] 
**document_date** | **date** | The date of the billing document, in &#x60;yyyy-mm-dd&#x60; format. It represents the invoice date for invoices, credit memo date for credit memos, and debit memo date for debit memos.  - If this field is specified, the specified date is used as the billing document date.  - If this field is not specified, the date specified in the &#x60;targetDate&#x60; is used as the billing document date.  | [optional] 
**include_existing_draft_doc_items** | **bool** | Specifies whether to include draft invoice items in subscription previews. Values are:  * &#x60;true&#x60; (default). Includes draft invoice items in the preview result. * &#x60;false&#x60;. Excludes draft invoice items in the preview result.  **Note:** This field is in Zuora REST API version control. Supported minor versions are 207.0 or later. To use this field in the method, you must set the **zuora-version** parameter to the minor version number in the request header. See [Zuora REST API Versions](https://www.zuora.com/developer/api-references/api/overview/#section/API-Versions) for more information.  | [optional] 
**include_existing_draft_invoice_items** | **bool** | Specifies whether to include draft invoice items in previews. Values are:  * &#x60;true&#x60; (default). Includes draft invoice items in the preview result. * &#x60;false&#x60;. Excludes draft invoice items in the preview result.  **Note:** This field is in Zuora REST API version control. Supported minor versions are 186.0, 187.0, 188.0, 189.0, 196.0, and 206.0. See [Zuora REST API Versions](https://www.zuora.com/developer/api-references/api/overview/#section/API-Versions) for more information.  | [optional] 
**initial_term** | **int** | Duration of the first term of the subscription, in whole months. If &#x60;termType&#x60; is &#x60;TERMED&#x60;, then this field is required, and the value must be greater than &#x60;0&#x60;. If &#x60;termType&#x60; is &#x60;EVERGREEN&#x60;, this field is ignored.      | [optional] 
**initial_term_period_type** | **str** | The period type of the initial term.   Supported values are:  * &#x60;Month&#x60; * &#x60;Year&#x60; * &#x60;Day&#x60; * &#x60;Week&#x60;   The default period type is &#x60;Month&#x60;.   | [optional] 
**invoice_owner_account_key** | **str** | Invoice owner account number or ID.  **Note:** This feature is in **Limited Availability**. If you wish to have access to the feature, submit a request at [Zuora Global Support](http://support.zuora.com/).  | [optional] 
**invoice_target_date** | **date** | Date through which to calculate charges if an invoice is generated, as yyyy-mm-dd. Default is current date.  **Note:** This field is in Zuora REST API version control. Supported minor versions are 186.0, 187.0, 188.0, 189.0, 196.0, and 206.0. See [Zuora REST API Versions](https://www.zuora.com/developer/api-references/api/overview/#section/API-Versions) for more information.  | [optional] 
**notes** | **str** | String of up to 500 characters. | [optional] 
**preview_account_info** | [**PreviewSubscriptionAccountInfo**](PreviewSubscriptionAccountInfo.md) |  | [optional] 
**preview_type** | **str** | The type of preview you will receive.   This field is in Zuora REST API version control. The supported values of this field depend on the REST API minor version you specified in the request header.   * If you do not specify the REST API minor version or specify the minor version number to one of following values in the request header:     * 186.0   * 187.0   * 188.0   * 189.0   * 196.0   * 206.0      The following values are supported in the **previewType** field:    * InvoiceItem   * ChargeMetrics   * InvoiceItemChargeMetrics      The default value is InvoiceItem.  * If you specify the REST API minor version to 207.0 or later in the request header, the following values are supported in the **previewType** field:    - LegalDoc   - ChargeMetrics   - LegalDocChargeMetrics    The default value is LegalDoc.  See [Zuora REST API Versions](https://www.zuora.com/developer/api-references/api/overview/#section/API-Versions) for more information.  | [optional] 
**service_activation_date** | **date** | The date on which the services or products within a subscription have been activated and access has been provided to the customer, as yyyy-mm-dd.  Default value is dependent on the value of other fields. See **Notes** section for more details.  | [optional] 
**subscribe_to_rate_plans** | [**List[CreateSubscriptionRatePlan]**](CreateSubscriptionRatePlan.md) | Container for one or more rate plans for this subscription.  | 
**target_date** | **date** | Date through which to calculate charges if an invoice is generated, as yyyy-mm-dd. Default is current date.  **Note:** This field is in Zuora REST API version control. Supported minor versions are 207.0 or later. To use this field in the method, you must set the **zuora-version** parameter to the minor version number in the request header. See [Zuora REST API Versions](https://www.zuora.com/developer/api-references/api/overview/#section/API-Versions) for more information.  | [optional] 
**term_start_date** | **date** | The date on which the subscription term begins, as yyyy-mm-dd. If this is a renewal subscription, this date is different from the subscription start date.  | [optional] 
**term_type** | **str** | Possible values are: &#x60;TERMED&#x60;, &#x60;EVERGREEN&#x60;.  | 

## Example

```python
from zuora_sdk.models.preview_subscription_request import PreviewSubscriptionRequest

# TODO update the JSON string below
json = "{}"
# create an instance of PreviewSubscriptionRequest from a JSON string
preview_subscription_request_instance = PreviewSubscriptionRequest.from_json(json)
# print the JSON string representation of the object
print(PreviewSubscriptionRequest.to_json())

# convert the object into a dict
preview_subscription_request_dict = preview_subscription_request_instance.to_dict()
# create an instance of PreviewSubscriptionRequest from a dict
preview_subscription_request_from_dict = PreviewSubscriptionRequest.from_dict(preview_subscription_request_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


